@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
  */
 
 #ifndef __MATE_ABOUT_C__
@@ -32,8 +32,6 @@
 	textdomain(package);
 #endif
 
-//class mate_about
-//{
 	#if GTK_CHECK_VERSION(3, 0, 0) && !defined(UNIQUE)
 
 	static void mate_about_on_activate(GtkApplication* app)
@@ -54,7 +52,8 @@
 	}
 
 	#elif GLIB_CHECK_VERSION(2, 26, 0) && !defined(UNIQUE)
-	// es un callback
+
+	// callback
 	static void mate_about_on_activate(GApplication* app)
 	{
 		if (!mate_about_dialog)
@@ -71,12 +70,10 @@
 
 	void mate_about_run(void)
 	{
-		/* Es importante llamar gtk_init, si no, no se puede iniciar bien el dialogo */
 		mate_about_dialog = (GtkAboutDialog*) gtk_about_dialog_new();
 
 		gtk_window_set_default_icon_name(icon);
 
-		/* logo */
 		#if GTK_CHECK_VERSION(3, 0, 0) || GTK_CHECK_VERSION(2, 6, 0)
 
 			gtk_about_dialog_set_logo_icon_name(mate_about_dialog, icon);
@@ -94,7 +91,7 @@
 
 		#endif
 
-		//name
+		// name
 		#if GTK_CHECK_VERSION(3, 0, 0) || GTK_CHECK_VERSION(2, 12, 0)
 			gtk_about_dialog_set_program_name(mate_about_dialog, gettext(program_name));
 		#else
@@ -104,7 +101,7 @@
 		// version
 		gtk_about_dialog_set_version(mate_about_dialog, version);
 
-		// creditos y pagina web
+		// credits and website
 		gtk_about_dialog_set_copyright(mate_about_dialog, copyright);
 		gtk_about_dialog_set_website(mate_about_dialog, website);
 
@@ -114,12 +111,12 @@
 		 */
 		gtk_about_dialog_set_comments(mate_about_dialog, gettext(comments_array[g_random_int_range(0, comments_count - 1)]));
 
-		// autores
 		gtk_about_dialog_set_authors(mate_about_dialog, authors);
-		// I comment this because the list is empty
 		gtk_about_dialog_set_artists(mate_about_dialog, artists);
 		gtk_about_dialog_set_documenters(mate_about_dialog, documenters);
-		gtk_about_dialog_set_translator_credits(mate_about_dialog, translators);
+		/* Translators should localize the following string which will be
+		 * displayed in the about box to give credit to the translator(s). */
+		gtk_about_dialog_set_translator_credits(mate_about_dialog, _("translator-credits"));
 
 		#if GTK_CHECK_VERSION(3, 0, 0)
 			gtk_about_dialog_set_license_type(mate_about_dialog, GTK_LICENSE_GPL_3_0);
@@ -141,44 +138,19 @@
 	{
 		int status = 0;
 
-		/* Con esto se inicia gettext
-		 * GETTEXT_PACKAGE = mate-desktop-2.0
-		 * LOCALE_DIR = /usr/local/share/locale */
 		mate_gettext(GETTEXT_PACKAGE, LOCALE_DIR, "UTF-8");
 
 		g_type_init();
-		
-		
-		#ifdef G_OPTIONS_ENTRY_USE
-			/* http://www.gtk.org/api/2.6/glib/glib-Commandline-option-parser.html */
-			GOptionContext* context = g_option_context_new(NULL);
-			g_option_context_add_main_entries(context, command_entries, GETTEXT_PACKAGE);
-			g_option_context_add_group(context, gtk_get_option_group(TRUE));
-			g_option_context_parse(context, &argc, &argv, NULL);
 
-			/* Not necesary at all, program just run and die.
-			 * But it free a little memory. */
-			g_option_context_free(context);
-		#else
-			int opt; /* este valor entrega el tipo de argumento */
-			
-			while ((opt = getopt_long(argc, argv, "+", command_entries, NULL)) != -1)
-			{
-				switch (opt)
-				{
-					case '?':
-						return 1;
-					case OPTION_VERSION:
-						mate_about_nogui = TRUE;
-						break;
-					#ifdef CMDLINE_PROCESS
-						CMDLINE_PROCESS
-					#endif
-				}
-			}
-		#endif
-		
-		
+		/* http://www.gtk.org/api/2.6/glib/glib-Commandline-option-parser.html */
+		GOptionContext* context = g_option_context_new(NULL);
+		g_option_context_add_main_entries(context, command_entries, GETTEXT_PACKAGE);
+		g_option_context_add_group(context, gtk_get_option_group(TRUE));
+		g_option_context_parse(context, &argc, &argv, NULL);
+
+		/* Not necesary at all, program just run and die.
+		 * But it free a little memory. */
+		g_option_context_free(context);
 
 		if (mate_about_nogui == TRUE)
 		{
@@ -189,7 +161,7 @@
 			gtk_init(&argc, &argv);
 
 			/**
-			 * Ejemplos tomados de:
+			 * Examples taken from:
 			 * http://developer.gnome.org/gtk3/3.0/gtk-migrating-GtkApplication.html
 			 */
 			#ifdef USE_UNIQUE
@@ -229,12 +201,13 @@
 				g_object_unref(mate_about_application);
 
 			#else
+
 				mate_about_run();
+
 			#endif
 		}
 
 		return status;
 	}
-//}
 
 #endif
